package viewer;

import javax.swing.*;
import java.awt.*;

/**
 * Helper class that receives calculations reports as they come from ICalcReport
 * interface. The class will update the progress dialog on each step report that
 * comes through the interface, and passes on the reports to the next listener,
 * like a pipe.
 */
public class CalculationsReport implements ICalcReport {
    /**
     * Next listener to ICalcReports.
     */
    private ICalcReport m_nextListener;

    private String[] m_statusStrings = {"Preparing Calculations Data",
                                        "Calculating",
                                        "Calculations finished",
                                        "Calculations aborted"};

    private ProgressBar progressBar;


    /**
     * @param nextListener The next listener in the pipe.
     * @param maxSteps The maximum number of steps to be made.
     */
    public CalculationsReport(ICalcReport nextListener, int maxSteps) {
        this.m_nextListener = nextListener;
        progressBar = new ProgressBar(maxSteps);

    }

    public void StatusChange(int status) {
        progressBar.setNote(m_statusStrings[status]);
        m_nextListener.StatusChange(status);
        if (status == ICalcReport.STATUS_FINISHED)
            progressBar.hide();
    }

    public void StepDone(StepData stepData) {
        progressBar.setValue(stepData.step);
        m_nextListener.StepDone(stepData);
    }

    public boolean isAborted() {
        return m_nextListener.isAborted();
    }
}
