package viewer;

import JSci.awt.AbstractGraphModel;
import JSci.awt.Graph2DModel;
import JSci.swing.JLineGraph;
import JSci.swing.JGraphLayout;

import javax.swing.*;
import java.awt.*;

/**
 * Frame containing the distance graph
 * Uses JSci package for the actual graph graphics
 */
public class DistanceGraph extends JFrame {
    private JPanel graphPane;
    private JLineGraph lineGraph;
    private float[] arrData;

    /**
     * @param data Input data for the graph
     */
    public DistanceGraph(double[] data) {
        int i;

        // Find the real length of the input array - without the trailing -1's
        for (i = 0; i < data.length; i++)
            if (data[i] == -1.0)
                break;

        arrData = new float[i];
        for (i = 0; i < arrData.length; i++)
            arrData[i] = (float) data[i];
        Container c = getContentPane();
        c.setLayout(new JGraphLayout());
        c.add("Graph", getGraphPane());
        c.add("X-axis", new JLabel("Step", JLabel.CENTER));
        c.add("Y-axis", new JLabel("Distance", JLabel.CENTER));
        c.add("Title", new JLabel("Distance graph as function of path length", JLabel.CENTER));
        setSize(600, 480);
        setTitle("Distance Graph");
    }

    private JLineGraph getLineGraph() {
        MyGraphModel model = new MyGraphModel();
        lineGraph = new JLineGraph(model);
        lineGraph.setXIncrement((float) Math.ceil((arrData.length + 1) / 10));
        lineGraph.setYIncrement(0.1f);
        lineGraph.setYExtrema(0.0f, 1.001f);
        lineGraph.setColor(0, Color.BLUE);
        return lineGraph;
    }

    private JPanel getGraphPane() {
        if (graphPane == null) {
            try {
                graphPane = new JPanel();
                graphPane.setLayout(new BorderLayout());
                graphPane.add(getLineGraph(), "Center");
            } catch (Throwable t) {
            }
        }
        return graphPane;
    }


    private class MyGraphModel
            extends AbstractGraphModel
            implements Graph2DModel {

        public void firstSeries() {
        }

        public boolean nextSeries() {
            return false;
        }

        public float getYCoord(int i) {
            return arrData[i];
        }

        public float getXCoord(int i) {
            return i + 1;
        }


        public int seriesLength() {
            return arrData.length;
        }
    }
}
