package viewer;

import java.awt.*;
import javax.swing.*;
import javax.swing.event.ChangeListener;
import javax.swing.event.ChangeEvent;

import JSci.awt.*;
import JSci.swing.*;


/**
 * Frame containing the permutations distribution graph
 * Uses JSci package for the actual graph graphics
*/
public class DistributionGraph extends JFrame implements ChangeListener {
    private JPanel graphPane;
    private JLineGraph lineGraph;
    private float[] arrData;
    private JSlider slider;

    private float maxVal, minVal;

    /**
     * @param data Input data for the graph
     */
    public DistributionGraph(double[] data) {
        int i;
        arrData = new float[data.length];
        maxVal = 0.0f;
        minVal = 2.0f;
        for (i = 0; i < data.length; i++) {
            arrData[i] = (float) data[i];
            maxVal = Math.max(maxVal, arrData[i]);
            minVal = Math.min(minVal, arrData[i]);
        }

        Container c = getContentPane();
        c.add(getGraphPane(), BorderLayout.CENTER);
        c.add(new JLabel("Probability", JLabel.CENTER), BorderLayout.WEST);
        slider = new JSlider(JSlider.VERTICAL, 1, 1000, 1);
        slider.setInverted(true);
        slider.addChangeListener(this);
        c.add(slider, BorderLayout.EAST);
        c.add(new JLabel("Distribution graph of the permutations (sorted)", JLabel.CENTER), BorderLayout.NORTH);

        setSize(600, 480);
        setTitle("Distribution Graph");
    }

    private JLineGraph getLineGraph() {
        if (lineGraph == null) {
            MyGraphModel model = new MyGraphModel();
            lineGraph = new JLineGraph(model);
            lineGraph.setXIncrement((float) Math.ceil((arrData.length + 1) / 10));
            lineGraph.setYIncrement(0.1f);
            lineGraph.setYExtrema(0.0f, 1.001f);
            lineGraph.setColor(0, Color.BLUE);
        }
        return lineGraph;
    }

    private JPanel getGraphPane() {
        if (graphPane == null) {
            try {
                graphPane = new JPanel();
                graphPane.setLayout(new BorderLayout());
                graphPane.add(getLineGraph(), "Center");
            } catch (Throwable t) {
            }
        }
        return graphPane;
    }

    /**
     * Updates the Y extremas due to scake slider changes
     * @param e
     */
    public void stateChanged(ChangeEvent e) {
        float resolution = ((1000 - slider.getValue()) / 1000f);
        float min = Math.max(0.0f, minVal - resolution);
        float max = Math.min(1.0001f, maxVal + resolution);
        getLineGraph().setYExtrema(min, max);
        lineGraph.setYIncrement((max - min) / 10);
    }


    private class MyGraphModel
            extends AbstractGraphModel
            implements Graph2DModel {

        public void firstSeries() {
        }

        public boolean nextSeries() {
            return false;
        }

        public float getYCoord(int i) {
            if (i == arrData.length)
                return 0;
            return arrData[i];
        }

        public float getXCoord(int i) {
            return Math.min(i + 1, arrData.length);
        }


        public int seriesLength() {
            return arrData.length;
        }
    }
}
