package viewer;

/**
 * Interface of listener to FlowGraph.
 * Methods are events that are reported by the Flow Graph to its listeners.
 */
public interface FlowGraphListener {

    /**
     * Called when user clicks a node.
     * @param layerNum Layer of the node.
     * @param layerIndex Index of the node in the layer.
     * @param button Button clicked.
     */
    public void nodeClicked(int layerNum, int layerIndex, int button);

    /**
     * Called when users clicks on an edge
     * (click is actually a mouse drag from one node to another).
     * @param sourceLayer Layer of the source node.
     * @param sourceIndex Index of the source node in its layer.
     * @param destLayer Layer of the destination node.
     * @param destIndex Index of the destination node in its layer.
     * @param button button clicked.
     */
    public void edgeClicked(int sourceLayer, int sourceIndex, int destLayer, int destIndex, int button);
}
