package viewer;

/**
 * The interface between the calculations unit and the other parts
 * the application
 */
public interface ICalculations {
    /**
     * Calculates (asynchroniously) probability functions for a run over
     * network with given parameters
     * @param netData Network data for the calculations
     * @return true if calculations started, false on error
     */
    public boolean StartCalculations(NetData netData);

    /**
     * Returns calculated data for given step
     * @param stepNum Which step data to return
     * @return StepData class containing the data, null on error
     */
    public StepData GetStepData(int stepNum);

    /**
     * Returns status of the MathUnit
     * @return STATUS_NOT_STARTED, STATUS_DONE or number of current step
     */
    public int GetCalcStatus();

    /**
     * Aborts currently running calculations
     * @return true on success, false on error
     */
    public boolean StopCalculations();

}