package viewer;

import java.awt.*;
import java.awt.event.*;
import java.util.Hashtable;
import javax.swing.*;
import javax.swing.event.*;

/**
 * Class that displays dialog for selecting threshold values for edges and nodes.
 */
public class ThresholdSlider extends JFrame implements ActionListener, ChangeListener {

    /**
     * Sensitivity of the sliders
     */
    private int sensitivity = 100;

    private String[] texts = {"Nodes threshold", "Edges threshold"};
    private float[] values = new float[2];
    private JSlider[] sliders = new JSlider[2];
    private JLabel[] arrlabels = new JLabel[2];
    private JButton bOK = new JButton("OK");
    private JButton bCancel = new JButton("Cancel");
    Controller controller;

    /**
     * Creating the Slider and initialized it to show the current threshold.
     * @param controller Object that will be informed of changes
     * @param oldNodesVal Old value of the nodes threshold
     * @param oldEdgesVal Old value of the edges threshold
     */
    public ThresholdSlider(Controller controller, float oldNodesVal, float oldEdgesVal) {
        super("Set thresholds");
        this.controller = controller;
        values[0] = oldNodesVal;
        values[1] = oldEdgesVal;

        Container c = getContentPane();
        c.setLayout(new GridLayout(5, 1));


        Hashtable labels = new Hashtable();
        labels.put(new Integer(0), new JLabel("0"));
        labels.put(new Integer(sensitivity / 4), new JLabel("0.25"));
        labels.put(new Integer(sensitivity / 2), new JLabel("0.5"));
        labels.put(new Integer((sensitivity * 3) / 4), new JLabel("0.75"));
        labels.put(new Integer(sensitivity), new JLabel("1"));

        for (int i = 0; i < 2; i++) {
            sliders[i] = new JSlider(SwingConstants.HORIZONTAL, 0, sensitivity, 1);
            sliders[i].setPaintTicks(true);
            sliders[i].setMinorTickSpacing(sensitivity / 20);
            sliders[i].setMajorTickSpacing(sensitivity / 4);
            sliders[i].setPaintLabels(true);
            sliders[i].setBorder(BorderFactory.createEmptyBorder(0, 0, 0, 10));
            sliders[i].setLabelTable(labels);
            sliders[i].setValue((int) (sensitivity * values[i]));
            sliders[i].addChangeListener(this);
            arrlabels[i] = new JLabel(texts[i] + ": " + Float.toString(values[i]), JLabel.CENTER);
            arrlabels[i].setVerticalAlignment(JLabel.BOTTOM);
            c.add(arrlabels[i]);
            c.add(sliders[i]);
        }
        bOK.addActionListener(this);
        bCancel.addActionListener(this);
        JPanel buttonPane = new JPanel();
        buttonPane.setLayout(new BoxLayout(buttonPane, BoxLayout.X_AXIS));
        buttonPane.setBorder(BorderFactory.createEmptyBorder(0, 10, 10, 10));
        buttonPane.add(Box.createHorizontalGlue());
        buttonPane.add(bCancel);
        buttonPane.add(Box.createRigidArea(new Dimension(10, 0)));
        buttonPane.add(bOK);
        c.add(buttonPane, BorderLayout.PAGE_END);
        setSize(400, 270);
        show();
    }

    public void stateChanged(ChangeEvent e) {
        int iSource = 0;
        JSlider source = (JSlider) e.getSource();
        if (source == sliders[1])
            iSource = 1;
        values[iSource] = ((float) source.getValue()) / sensitivity;
        arrlabels[iSource].setText(texts[iSource] + ": " + Float.toString(values[iSource]));
        this.repaint();
    }

    /**
     * Action listener for the submit button and the cancel button.
     * @param e
     */
    public void actionPerformed(ActionEvent e) {
        if (e.getSource() == bOK) {
            hide();
            controller.setThresholds(values[0], values[1]);
        } else if (e.getSource() == bCancel) {
            hide();
        }
    }

}